@@ -1,18 +1,17 @@
 package Weed::FieldTypes::SFInt32;
 
-our $VERSION = '0.01';
+our $VERSION = '0.009';
 
 use Weed 'SFInt32 : X3DField { 0 }';
 
-use integer;
-
 use base 'Weed::BaseFieldTypes::Scalar';
 
+use Weed::Parse::Int32;
+
 sub setValue {
 	my ( $this, $value ) = @_;
-	
 	$this->X3DField::setValue(
-		defined $value ? eval { no warnings; int($value) } || 0 : $this->getDefaultValue
+		defined $value ? Weed::Parse::Int32::int32( \"$value" ) || 0 : $this->getDefaultValue
 	);
 }
 
