@@ -1,7 +1,7 @@
 package Weed::Package;
 use Weed::Perl;
 
-our $VERSION = '0.013';
+our $VERSION = '0.009';
 
 #use Package::Generator;
 #Symbol::delete_package wipes out a whole package namespace. Note this routine is not exported by default--you may want to import it explicitly.
@@ -16,8 +16,6 @@ use Weed::Parse::Concept;
 our $_space     = qr/\s+/so;
 our $_type_name = qr/^([\$\@%&*]?)(.*)/so;
 
-our $Namespace = "";
-
 sub import {
 	my $to = shift;
 
@@ -45,27 +43,26 @@ sub exists { UNIVERSAL::can( $_[0], 'can' ) ? YES : NO }
 sub createType {
 	my ( $package, $base, $declaration, @imports ) = @_;
 
+	#printf "X3DUniversal createType %s %s\n", $package, $base;
+
 	my $description = Weed::Parse::Concept::parse($declaration);
 	if ( ref $description ) {
 
 		my $typeName = $description->{typeName};
 
-		my $packageName = $Namespace ? "$Namespace\::$typeName" : $typeName;
-		#printf "X3DUniversal createType %s %s %s %s\n", $package, $base, $typeName, $packageName;
-
-		X3DPackage::setBase( $packageName, $package, @imports );
-		X3DPackage::setSupertypes( $packageName,
+		X3DPackage::setBase( $typeName, $package, @imports );
+		X3DPackage::setSupertypes( $typeName,
 			@{ $description->{supertypes} } ?
 			  @{ $description->{supertypes} } :
 			  $base
 		);
-		#X3DPackage::setBase( $typeName, $description->{base} );
+		X3DPackage::setBase( $typeName, $description->{base} );
 
 		#printf "X3DUniversal createType %s : %s %s\n", $typeName, $package, $base;
-		X3DPackage::Scalar( $packageName, "Description" ) = $description;
+		X3DPackage::Scalar( $typeName, "Description" ) = $description;
 
-		$packageName->SET_DESCRIPTION($description)
-		  if $packageName->can('SET_DESCRIPTION');
+		$typeName->SET_DESCRIPTION($description)
+		  if $typeName->can('SET_DESCRIPTION');
 
 	} else {
 		Carp::croak "Error Parse::Concept: '$declaration'\n", $@ if $@;
@@ -76,57 +73,17 @@ sub createType {
 
 sub getName { ref( $_[0] ) || $_[0] }
 
-sub getNamespace { $Namespace }
-sub setNamespace { $Namespace = $_[1] || '' }
+sub getSuperpath        { Class::ISA::super_path( X3DPackage::getName(shift) ) }
+sub getSelfAndSuperpath { Class::ISA::self_and_super_path( X3DPackage::getName(shift) ) }
 
-#sub getPath { [ Class::ISA::self_and_super_path( X3DPackage::getName( $_[0] ) ) ] }
-sub getPath {
-	my $package = $_[0];
-
-	Carp::croak "Package '$package' does not exists."
-	  unless X3DPackage::exists($package);
-
-	unless ( defined $package->X3DPackage::Scalar('X3DPath') )
-	{
-		my @path;
-		my @supertypes = ( X3DPackage::getName($package) );
-
-		while (@supertypes) {
-			$_ = shift @supertypes;
-			unshift @path,       $_;
-			unshift @supertypes, @{ X3DPackage::getSupertypes($_) };
-		}
-
-		my $type;
-		my $path;
-		foreach (@path) {
-			unshift @$path, $_ unless exists $type->{$_};
-			$type->{$_} = 1;
-		}
-
-		$package->X3DPackage::Scalar('Path') = $path;
-	}
-
-	return $package->X3DPackage::Scalar('Path');
-}
-
-#sub getSuperpath {
-#	my $package = X3DPackage::getName( $_[0] );
-#	[ Class::ISA::super_path($package) ]
-#}
+#&\w(\w|::)*>|<\w(\w|::)*(?=\s*[\(\);])
 
 sub getSupertype {
-	my $package = $_[0];
-
-	Carp::croak "Package '$package' does not exists."
-	  unless X3DPackage::exists($package);
-
-	my $isa = \X3DPackage::Array( $_[0], 'ISA' );
-
-	return $isa->[0] if @$isa;
+	my @path = Class::ISA::super_path( X3DPackage::getName(shift) );
+	return shift @path;
 }
 
-sub getSupertypes { [ X3DPackage::Array( $_[0], 'ISA' ) ] }
+sub getSupertypes { X3DPackage::Array( shift, 'ISA' ) }
 
 sub setSupertypes {
 	my $package = shift;
@@ -288,54 +245,48 @@ sub get_rename_string {
 
 ##
 
+no strict 'refs';
+no warnings;
+
 sub Scalar : lvalue {
 	my ( $this, $name ) = @_;
 	my $property = sprintf '%s::%s', $this->X3DPackage::getName, $name;
-	no strict 'refs';
-	no warnings;
 	$$property;
 }
 
+use warnings;
+
 sub Array : lvalue {
 	my ( $this, $name ) = @_;
 	my $property = sprintf '%s::%s', $this->X3DPackage::getName, $name;
-	no strict 'refs';
 	@$property;
 }
 
 sub Hash : lvalue {
 	my ( $this, $name ) = @_;
 	my $property = sprintf '%s::%s', $this->X3DPackage::getName, $name;
-	no strict 'refs';
 	%$property;
 }
 
-sub Glob : lvalue {
-	my ( $this, $name ) = @_;
-	my $property = sprintf '%s::%s', $this->X3DPackage::getName, $name;
-	no strict 'refs';
-	*$property;
-}
+# sub can {
+# 	my ( $this, $name ) = @_;
+# 	my $property = sprintf "%s::%s::can::%s", __PACKAGE__, $this->X3DPackage::getName, $name;
+#
+# 	unless ( defined $$property ) {
+# 		$$property = [];
+# 		push @$$property, map { \&{"${_}::${name}"} }
+# 		  grep { exists &{"${_}::${name}"} } X3DPackage::getSelfAndSuperpath($this);
+# 	}
+#
+# 	return @$$property;
+# }
 
-sub getSubroutine {
-	my ( $this, $name ) = @_;
-	my $property = sprintf "%s::X3DSubroutine::%s", $this->X3DPackage::getName, $name;
+use strict 'refs';
 
-	no strict 'refs';
-	unless ( defined $$property ) {
-		$$property = [];
-		push @$$property, reverse map { \&{"${_}::${name}"} }
-		  grep { exists &{"${_}::${name}"} } @{ X3DPackage::getPath($this) };
-	}
-
-	return $$property;
-}
-
-sub Call {
-	my ( $this, $name ) = ( shift, shift );
-	$_->( $this, @_ ) foreach @{ $this->X3DPackage::getSubroutine($name) };
-	return;
-}
+#sub call {
+#	my ( $this, $name ) = ( shift, shift );
+#	return map { &$_( $this, @_ ) } X3DPackage::can( $this, $name );
+#}
 
 #sub reverse_call {
 #	my ( $this, $name ) = ( shift, shift );
@@ -349,8 +300,9 @@ sub toString {
 	my $level   = shift || 1;
 	my $string  = '';
 
-	Carp::croak "Package '$package' does not exists."
-	  unless X3DPackage::exists($package);
+	unless ( X3DPackage::exists($package) ) {
+		Carp::croak "Package $package does not exists.";
+	}
 
 	$string .= $package->X3DPackage::getName;
 
